<TS language="id_ID" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Klik-kanan untuk mengubah alamat atau label</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Buat alamat baru</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Baru</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Salin alamat yang dipilih ke clipboard</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Salin</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>T&amp;utup</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Hapus alamat yang sementara dipilih dari daftar</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Masukkan alamat atau label untuk mencari</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Ekspor data dalam tab sekarang ke sebuah berkas</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Ekspor</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Hapus</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Pilih alamat untuk mengirim koin</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Piih alamat untuk menerima koin</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;Pilih</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Alamat-alamat pengirim</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Alamat-alamat penerima</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Berikut ialah alamat-alamat Litecoin Anda yang digunakan untuk mengirimkan pembayaran. Selalu periksa jumlah dan alamat penerima sebelum mengirimkan koin.</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>Berikut ialah alamat-alamat Litecoin Anda yang digunakan untuk menerima pembayaran. Dianjurkan untuk menggunakan alamat penerimaan baru untuk setiap transaksi.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Salin Alamat</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Salin&amp; Label</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Ubah</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Ekspor Daftar Alamat</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Berkas CSV (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Gagal Mengekspor</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Terjadi kesalahan saat mencoba menyimpan daftar alamat ke %1. Silakan coba lagi.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Alamat</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(tidak ada label)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dialog Kata Sandi</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Masukkan kata sandi</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Kata sandi baru</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ulangi kata sandi baru</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>Tampilkan kata sandi</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Masukan kata sandi baru ke dompet.&lt;br/&gt;Mohon gunakan kata sandi &lt;b&gt;sepuluh karakter acak atau lebih&lt;/b&gt;, atau &lt;b&gt; delapan atau lebih beberapa kata &lt;/​​b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Enkripsi dompet</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Operasi ini memerlukan kata sandi dompet Anda untuk membuka dompet.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Buka dompet</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Operasi ini memerlukan kata sandi dompet Anda untuk mendekripsikan dompet.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Dekripsi dompet</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Ganti kata sandi</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>Masukkan kata sandi lama dan kata sandi baru ke dompet.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Konfirmasi pengenkripsian dompet</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR LITECOINS&lt;/b&gt;!</source>
        <translation>Peringatan: Jika Anda mengenkripsi dompet Anda dan lupa kata sandi Anda, Anda akan &lt;b&gt;KEHILANGAN SEMUA LITECOIN ANDA&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Apakah Anda yakin ingin enkripsi dompet Anda?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Dompet terenkripsi</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. Remember that encrypting your wallet cannot fully protect your litecoins from being stolen by malware infecting your computer.</source>
        <translation>Wallet anda sekarang telah terenkripsi. Ingat bahwa enkripsi wallet anda tersebut tidak dapat sepenuhnya melindungi dari pencurian atau malware yang menyerang komputer anda. </translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>PENTING: Backup sebelumnya yang Anda buat dari file dompet Anda harus diganti dengan file dompet terenkripsi yang baru dibuat. Demi keamanan, backup file dompet sebelumnya yang tidak dienkripsi sebelumnya akan menjadi tidak berguna begitu Anda mulai menggunakan dompet terenkripsi yang baru.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Pengenkripsian dompet gagal</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Pengenkripsian dompet gagal karena kesalahan internal. Dompet Anda tidak dienkripsi.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Kata sandi yang dimasukkan tidak cocok.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Membuka dompet gagal</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Kata sandi yang dimasukkan untuk dekripsi dompet salah.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Dekripsi dompet gagal</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Kata sandi berhasil diganti.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Peringatan: Tombol Caps Lock aktif!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Netmask</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Di banned sampai</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Pesan &amp;penanda...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Sinkronisasi dengan jaringan...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Kilasan</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Tampilkan gambaran umum dompet Anda</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transaksi</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Lihat riwayat transaksi</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>K&amp;eluar</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Keluar dari aplikasi</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Tentang%1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Tampilkan informasi perihal %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Mengenai &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Tampilkan informasi mengenai Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Pilihan...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Pengubahan opsi konfigurasi untuk %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Enkripsi Dompet...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;Cadangkan Dompet...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Ubah Kata Kunci...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Buka &amp;URI</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Wallet:</translation>
    </message>
    <message>
        <source>Click to disable network activity.</source>
        <translation>Klik untuk menonaktifkan aktivitas jaringan.</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <translation>Aktivitas jaringan dinonaktifkan.</translation>
    </message>
    <message>
        <source>Click to enable network activity again.</source>
        <translation>Klik untuk mengaktifkan aktivitas jaringan lagi.</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>Menyinkronkan Header (%1%) ...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Mengindex ulang blok di dalam disk...</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation>Proxy di &lt;b&gt;aktifkan&lt;/b&gt;: %1</translation>
    </message>
    <message>
        <source>Send coins to a Litecoin address</source>
        <translation>Kirim koin ke alamat Litecoin</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Cadangkan dompet ke lokasi lain</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Ubah kata kunci yang digunakan untuk enkripsi dompet</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Jendela Debug</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Buka konsol debug dan diagnosa</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verifikasi pesan...</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Kirim</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Menerima</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Tampilkan / Sembunyikan</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Tampilkan atau sembunyikan jendela utama</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Enkripsi private key yang dimiliki dompet Anda</translation>
    </message>
    <message>
        <source>Sign messages with your Litecoin addresses to prove you own them</source>
        <translation>Tanda tangani sebuah pesan menggunakan alamat Litecoin Anda untuk membuktikan bahwa Anda adalah pemilik alamat tersebut</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Litecoin addresses</source>
        <translation>Verifikasi pesan untuk memastikan bahwa pesan tersebut ditanda tangani oleh suatu alamat Litecoin tertentu</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Berkas</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Pengaturan</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Bantuan</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Baris tab</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and litecoin: URIs)</source>
        <translation>Permintaan pembayaran (membuat kode QR dan litecoin: URIs)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Tampilkan daftar alamat dan label yang terkirim</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Tampilkan daftar alamat dan label yang diterima</translation>
    </message>
    <message>
        <source>Open a litecoin: URI or payment request</source>
        <translation>Buka URI litecoin: atau permintaan pembayaran</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;pilihan Command-line</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Litecoin network</source>
        <translation><numerusform>%n koneksi aktif ke jaringan Litecoin</numerusform></translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Pengindeksan blok pada disk ...</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>Memproses blok pada disk ...</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation><numerusform>%n blok dari riwayat transaksi diproses.</numerusform></translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>kurang %1</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Blok terakhir yang diterima %1 lalu.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Transaksi setelah ini belum akan terlihat.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Terjadi sebuah kesalahan</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Peringatan</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informasi</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Terbaru</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation>&amp;Address pengiriman</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation>&amp;Address penerima</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Litecoin command-line options</source>
        <translation>Tampilkan %1 pesan bantuan untuk mendapatkan daftar opsi baris perintah Litecoin yang memungkinkan</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation>wallet default</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Jendela</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimalkan</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Pulihkan</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation>Jendela Utama</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 klien</translation>
    </message>
    <message>
        <source>Connecting to peers...</source>
        <translation>Menghubungkan ke peer...</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Menyusul...</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Tanggal: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Jumlah: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation>Wallet: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Tipe: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Label: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Alamat: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transaksi terkirim</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transaksi diterima</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation>Pembuatan kunci HD &lt;b&gt;diaktifkan&lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation>Pembuatan kunci HD &lt;b&gt;dinonaktifkan&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation>Private key &lt;b&gt;non aktif&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Dompet saat ini &lt;b&gt;terenkripsi&lt;/b&gt; dan &lt;b&gt;terbuka&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Dompet saat ini &lt;b&gt;terenkripsi&lt;/b&gt; dan &lt;b&gt;terkunci&lt;/b&gt;</translation>
    </message>
    <message>
        <source>A fatal error occurred. Litecoin can no longer continue safely and will quit.</source>
        <translation>Terjadi Kesalahan Fatal. Litecoin Tidak Dapat Melanjutkan Dengan Aman Dan Akan Keluar</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>Pemilihan Koin</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Kuantitas:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bytes:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Jumlah:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Biaya:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Dust:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Dengan Biaya:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Kembalian:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>(Tidak)memilih semua</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>Tree mode</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>Mode daftar</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Jumlah</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>Diterima dengan label</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>Diterima dengan alamat</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Tanggal</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Konfirmasi</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Terkonfirmasi</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Salin alamat</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Salin label</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Salin Jumlah</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Salain ID Transaksi</translation>
    </message>
    <message>
        <source>Lock unspent</source>
        <translation>Kunci Yang Tidak Digunakan</translation>
    </message>
    <message>
        <source>Unlock unspent</source>
        <translation>Buka Kunci Yang Tidak Digunakan</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Salin Kuantitas</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Salin biaya</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Salin Setelah Upah</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Salin bytes</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Salin jumlah yang lebih kecil</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Salin Perubahan</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation>(%1 terkunci)</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>Ya</translation>
    </message>
    <message>
        <source>no</source>
        <translation>Tidak</translation>
    </message>
    <message>
        <source>Can vary +/- %1 satoshi(s) per input.</source>
        <translation>Dapat bervariasi +/- %1 satoshi per input.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(tidak ada label)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>kembalian dari %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(kembalian)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Ubah Alamat</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Label</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation>Label yang terkait dengan daftar alamat</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation>Alamat yang terkait dengan daftar alamat. Hanya dapat diubah untuk alamat pengirim.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Alamat</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Alamat pengirim baru</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Ubah alamat penerima</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Ubah alamat pengirim</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Litecoin address.</source>
        <translation>Alamat yang dimasukkan "%1" bukanlah alamat Litecoin yang valid.</translation>
    </message>
    <message>
        <source>Address "%1" already exists as a receiving address with label "%2" and so cannot be added as a sending address.</source>
        <translation>Alamat "%1" sudah ada sebagai alamat penerimaan dengan label "%2" sehingga tidak bisa ditambah sebagai alamat pengiriman.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book with label "%2".</source>
        <translation>Alamat "%1" yang dimasukkan sudah ada di dalam buku alamat dengan label "%2".</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Tidak dapat membuka dompet.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Pembuatan kunci baru gagal.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>Sebuah data direktori baru telah dibuat.</translation>
    </message>
    <message>
        <source>name</source>
        <translation>nama</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation>Direktori masih ada. Tambahlah %1 apabila Anda ingin membuat direktori baru disini.</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation>Sudah ada path, dan itu bukan direktori.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>Tidak bisa membuat direktori data disini.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>versi</translation>
    </message>
    <message>
        <source>(%1-bit)</source>
        <translation>(%1-bit)</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Tentang %1</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Pilihan Command-line</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Selamat Datang</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation>Selamat Datang di %1.</translation>
    </message>
    <message>
        <source>As this is the first time the program is launched, you can choose where %1 will store its data.</source>
        <translation>Karena ini adalah pertama kalinya program dijalankan, Anda dapat memilih lokasi %1 akan menyimpan data.</translation>
    </message>
    <message>
        <source>When you click OK, %1 will begin to download and process the full %4 block chain (%2GB) starting with the earliest transactions in %3 when %4 initially launched.</source>
        <translation>Ketika Anda mengklik OK, %1 akan mulai mengunduh dan memproses %4 block chain penuh (%2GB), dimulai dari transaksi-transaksi awal di %3 saat %4 diluncurkan pertama kali.</translation>
    </message>
    <message>
        <source>This initial synchronisation is very demanding, and may expose hardware problems with your computer that had previously gone unnoticed. Each time you run %1, it will continue downloading where it left off.</source>
        <translation>Sinkronisasi awal sangat berat dan mungkin akan menunjukkan permasalahan pada perangkat keras komputer Anda yang sebelumnya tidak tampak. Setiap kali Anda menjalankan %1, aplikasi ini akan melanjutkan pengunduhan dari posisi terakhir.</translation>
    </message>
    <message>
        <source>If you have chosen to limit block chain storage (pruning), the historical data must still be downloaded and processed, but will be deleted afterward to keep your disk usage low.</source>
        <translation>Apabila Anda memilih untuk membatasi penyimpanan block chain (pruning), data historis tetap akan diunduh dan diproses. Namun, data akan dihapus setelahnya untuk menjaga pemakaian disk agar tetap sedikit.</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation>Gunakan direktori data default.</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation>Gunakan direktori pilihan Anda:</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>At least %1 GB of data will be stored in this directory, and it will grow over time.</source>
        <translation>Setidaknya %1 GB data akan disimpan di direktori ini dan akan berkembang seiring berjalannya waktu.</translation>
    </message>
    <message>
        <source>Approximately %1 GB of data will be stored in this directory.</source>
        <translation>%1 GB data akan disimpan di direktori ini.</translation>
    </message>
    <message>
        <source>%1 will download and store a copy of the Litecoin block chain.</source>
        <translation>%1 akan mengunduh dan menyimpan salinan Litecoin block chain.</translation>
    </message>
    <message>
        <source>The wallet will also be stored in this directory.</source>
        <translation>Dompet juga akan disimpan di direktori ini.</translation>
    </message>
    <message>
        <source>Error: Specified data directory "%1" cannot be created.</source>
        <translation>Kesalahan: Direktori data "%1" tidak dapat dibuat.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Kesalahan</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation><numerusform>%n GB ruang kosong tersedia.</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation><numerusform>(dari %n GB yang dibutuhkan)</numerusform></translation>
    </message>
</context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Formulir</translation>
    </message>
    <message>
        <source>Recent transactions may not yet be visible, and therefore your wallet's balance might be incorrect. This information will be correct once your wallet has finished synchronizing with the litecoin network, as detailed below.</source>
        <translation>Transaksi-transaksi terkini mungkin belum terlihat dan oleh karenanya, saldo dompet Anda mungkin tidak tepat. Informasi ini akan akurat ketika dompet Anda tersinkronisasi dengan jaringan Litecoin, seperti rincian berikut.</translation>
    </message>
    <message>
        <source>Attempting to spend litecoins that are affected by not-yet-displayed transactions will not be accepted by the network.</source>
        <translation>Usaha untuk menggunakan litecoin yang dipengaruhi oleh transaksi yang belum terlihat tidak akan diterima oleh jaringan.</translation>
    </message>
    <message>
        <source>Number of blocks left</source>
        <translation>Jumlah blok tersisa</translation>
    </message>
    <message>
        <source>Unknown...</source>
        <translation>Tidak diketahui...</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Waktu blok terakhir</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Perkembangan</translation>
    </message>
    <message>
        <source>Progress increase per hour</source>
        <translation>Peningkatan perkembangan per jam</translation>
    </message>
    <message>
        <source>calculating...</source>
        <translation>menghitung...</translation>
    </message>
    <message>
        <source>Estimated time left until synced</source>
        <translation>Estimasi waktu tersisa sampai tersinkronisasi</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Sembunyikan</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Open URI</source>
        <translation>Buka URI</translation>
    </message>
    <message>
        <source>Open payment request from URI or file</source>
        <translation>Buka permintaan pembayaran dari URI atau data</translation>
    </message>
    <message>
        <source>URI:</source>
        <translation>URI:</translation>
    </message>
    <message>
        <source>Select payment request file</source>
        <translation>Pilih data permintaan pembayaran</translation>
    </message>
    <message>
        <source>Select payment request file to open</source>
        <translation>Pilih data permintaan pembayaran yang akan dibuka</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Pilihan</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Utama</translation>
    </message>
    <message>
        <source>Automatically start %1 after logging in to the system.</source>
        <translation>Mulai %1 secara otomatis setelah masuk ke dalam sistem.</translation>
    </message>
    <message>
        <source>&amp;Start %1 on system login</source>
        <translation>Mulai %1 ketika masuk ke &amp;sistem</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation>Ukuran cache &amp;database</translation>
    </message>
    <message>
        <source>Number of script &amp;verification threads</source>
        <translation>Jumlah script &amp;verification threads</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation>Alamat IP proxy (cth. IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>Shows if the supplied default SOCKS5 proxy is used to reach peers via this network type.</source>
        <translation>Perlihatkan apabila proxy SOCKS5 default digunakan untuk berhungan dengan orang lain lewat tipe jaringan ini.</translation>
    </message>
    <message>
        <source>Use separate SOCKS&amp;5 proxy to reach peers via Tor hidden services:</source>
        <translation>Menggunakan proxy SOCKS5 tersendiri untuk berhubungan dengan orang lain melalui layanan Tor:</translation>
    </message>
    <message>
        <source>Hide the icon from the system tray.</source>
        <translation>Sembunyikan ikon dari system tray.</translation>
    </message>
    <message>
        <source>&amp;Hide tray icon</source>
        <translation>&amp;Sembunyikan ikon tray</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Exit in the menu.</source>
        <translation>Minimalisasi aplikasi ketika jendela ditutup. Ketika pilihan ini dipilih, aplikasi akan menutup seluruhnya jika anda memilih Keluar di menu yang tersedia.</translation>
    </message>
    <message>
        <source>Third party URLs (e.g. a block explorer) that appear in the transactions tab as context menu items. %s in the URL is replaced by transaction hash. Multiple URLs are separated by vertical bar |.</source>
        <translation>URL pihak ketika (misalnya sebuah block explorer) yang mumcul dalam tab transaksi sebagai konteks menu. %s dalam URL diganti dengan kode transaksi. URL dipisahkan dengan tanda vertikal |.</translation>
    </message>
    <message>
        <source>Open the %1 configuration file from the working directory.</source>
        <translation>Buka file konfigurasi %1 dari direktori kerja.</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation>Buka Berkas Konfigurasi</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation>Kembalikan semua pengaturan ke awal.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation>&amp;Reset Pilihan</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Jaringan</translation>
    </message>
    <message>
        <source>Disables some advanced features but all blocks will still be fully validated. Reverting this setting requires re-downloading the entire blockchain. Actual disk usage may be somewhat higher.</source>
        <translation>Menonaktifkan beberapa fitur canggih akan tetapi semua block akan tetap divalidasi seutuhnya. Mengembalikan pengaturan ini memerlukan untuk mengunduh seluruh blockchain. Penggunaan disk mungkin akan lebih tinggi.</translation>
    </message>
    <message>
        <source>Prune &amp;block storage to</source>
        <translation>Prune &amp;ruang penyimpan block ke</translation>
    </message>
    <message>
        <source>GB</source>
        <translation>GB</translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain.</source>
        <translation>Mengembalikan pengaturan ini membutuhkan pengunduhan seluruh blockchain lagi. </translation>
    </message>
    <message>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>(0 = auto, &lt;0 = leave that many cores free)</source>
        <translation>(0 = auto, &lt;0 = leave that many cores free)</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>D&amp;ompet</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Ahli</translation>
    </message>
    <message>
        <source>Enable coin &amp;control features</source>
        <translation>Perbolehkan fitur &amp;pengaturan koin</translation>
    </message>
    <message>
        <source>If you disable the spending of unconfirmed change, the change from a transaction cannot be used until that transaction has at least one confirmation. This also affects how your balance is computed.</source>
        <translation>Jika Anda menonaktifkan perubahan saldo untuk transaksi yang belum dikonfirmasi, perubahan dari transaksi tidak dapat dilakukan sampai transaksi memiliki setidaknya satu konfirmasi. Hal ini juga mempengaruhi bagaimana saldo Anda dihitung.</translation>
    </message>
    <message>
        <source>&amp;Spend unconfirmed change</source>
        <translation>&amp;Perubahan saldo untuk transaksi yang belum dikonfirmasi</translation>
    </message>
    <message>
        <source>Automatically open the Litecoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Otomatis membuka port client Litecoin di router. Hanya berjalan apabila router anda mendukung UPnP dan di-enable.</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Petakan port dengan &amp;UPnP</translation>
    </message>
    <message>
        <source>Accept connections from outside.</source>
        <translation>Terima koneksi-koneksi dari luar.</translation>
    </message>
    <message>
        <source>Allow incomin&amp;g connections</source>
        <translation>Terima koneksi-koneksi masuk</translation>
    </message>
    <message>
        <source>Connect to the Litecoin network through a SOCKS5 proxy.</source>
        <translation>Hubungkan ke jaringan Litecoin melalui SOCKS5 proxy.</translation>
    </message>
    <message>
        <source>&amp;Connect through SOCKS5 proxy (default proxy):</source>
        <translation>&amp;Hubungkan melalui proxy SOCKS5 (proxy default):</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation>IP Proxy:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Port:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Port proxy (cth. 9050)</translation>
    </message>
    <message>
        <source>Used for reaching peers via:</source>
        <translation>Digunakan untuk berhubungan dengan peers melalui:</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Tor</source>
        <translation>Tor</translation>
    </message>
    <message>
        <source>Connect to the Litecoin network through a separate SOCKS5 proxy for Tor hidden services.</source>
        <translation>Koneksi ke jaringan litecoin melalui proxy SOCKS5 yang berbeda untuk layanan Tor tersembunyi.</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Jendela</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Hanya tampilkan ikon tray setelah meminilisasi jendela</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Meminilisasi ke tray daripada taskbar</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;eminilisasi saat tutup</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Tampilan</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Bahasa Antarmuka Pengguna:</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting %1.</source>
        <translation>Bahasa tampilan dapat diatur di sini. Pengaturan ini akan berpengaruh setelah memulai ulang %1.</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Unit untuk menunjukkan nilai:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Pilihan standar unit yang ingin ditampilkan pada layar aplikasi dan saat mengirim koin.</translation>
    </message>
    <message>
        <source>Whether to show coin control features or not.</source>
        <translation>Ingin menunjukkan cara pengaturan koin atau tidak.</translation>
    </message>
    <message>
        <source>&amp;Third party transaction URLs</source>
        <translation>&amp;URL transaksi pihak ketiga</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;YA</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Batal</translation>
    </message>
    <message>
        <source>default</source>
        <translation>standar</translation>
    </message>
    <message>
        <source>none</source>
        <translation>tidak satupun</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <translation>Memastikan reset pilihan</translation>
    </message>
    <message>
        <source>Client restart required to activate changes.</source>
        <translation>Restart klien diperlukan untuk mengaktifkan perubahan.</translation>
    </message>
    <message>
        <source>Client will be shut down. Do you want to proceed?</source>
        <translation>Klien akan dimatikan, apakah anda hendak melanjutkan?</translation>
    </message>
    <message>
        <source>Configuration options</source>
        <translation>Konfigurasi pengaturan</translation>
    </message>
    <message>
        <source>The configuration file is used to specify advanced user options which override GUI settings. Additionally, any command-line options will override this configuration file.</source>
        <translation>File konfigurasi digunakan untuk menspesifikkan pilihan khusus pengguna yang akan menimpa pengaturan GUI. Sebagai tambahan, pengaturan command-line apapun akan menimpa file konfigurasi itu.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Terjadi sebuah kesalahan</translation>
    </message>
    <message>
        <source>The configuration file could not be opened.</source>
        <translation>Berkas konfigurasi tidak dapat dibuka.</translation>
    </message>
    <message>
        <source>This change would require a client restart.</source>
        <translation>Perubahan ini akan memerlukan restart klien</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Alamat proxy yang diisi tidak valid.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formulir</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Litecoin network after a connection is established, but this process has not completed yet.</source>
        <translation>Informasi terlampir mungkin sudah kedaluwarsa. Dompet Anda secara otomatis mensinkronisasi dengan jaringan Litecoin ketika sebuah hubungan terbentuk, namun proses ini belum selesai.</translation>
    </message>
    <message>
        <source>Watch-only:</source>
        <translation>Hanya lihat:</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Tersedia:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Jumlah yang Anda bisa keluarkan sekarang</translation>
    </message>
    <message>
        <source>Pending:</source>
        <translation>Ditunda</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the spendable balance</source>
        <translation>Jumlah keseluruhan transaksi yang belum dikonfirmasi, dan belum saatnya dihitung sebagai pengeluaran saldo yang telah dibelanjakan.</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Terlalu Muda:</translation>
    </message>
    <message>
        <source>Mined balance that has not yet matured</source>
        <translation>Saldo ditambang yang masih terlalu muda</translation>
    </message>
    <message>
        <source>Balances</source>
        <translation>Saldo:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Jumlah:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Jumlah saldo Anda sekarang</translation>
    </message>
    <message>
        <source>Your current balance in watch-only addresses</source>
        <translation>Saldomu di alamat hanya lihat</translation>
    </message>
    <message>
        <source>Spendable:</source>
        <translation>Bisa digunakan:</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation>Transaksi-transaksi terkini</translation>
    </message>
    <message>
        <source>Unconfirmed transactions to watch-only addresses</source>
        <translation>Transaksi yang belum terkonfirmasi ke alamat hanya lihat</translation>
    </message>
    <message>
        <source>Mined balance in watch-only addresses that has not yet matured</source>
        <translation>Saldo hasil mining di alamat hanya lihat yang belum bisa digunakan</translation>
    </message>
    <message>
        <source>Current total balance in watch-only addresses</source>
        <translation>Jumlah saldo di alamat hanya lihat</translation>
    </message>
</context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Payment request error</source>
        <translation>Terjadi kesalahan pada permintaan pembayaran</translation>
    </message>
    <message>
        <source>Cannot start litecoin: click-to-pay handler</source>
        <translation>Tidak bisa memulai litecoin: handler click-to-pay</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>Pengelolaan URI</translation>
    </message>
    <message>
        <source>'litecoin://' is not a valid URI. Use 'litecoin:' instead.</source>
        <translation>'litecoin://' bukanlah alamat URI yang valid. Silakan gunakan 'litecoin:'.</translation>
    </message>
    <message>
        <source>Payment request fetch URL is invalid: %1</source>
        <translation>URL permintaan pembayaran tidak valid: %1</translation>
    </message>
    <message>
        <source>URI cannot be parsed! This can be caused by an invalid Litecoin address or malformed URI parameters.</source>
        <translation>URI tidak bisa dimengerti! Hal ini bisa disebabkan karena alamat Litecoin yang tidak sah atau parameter URI yang tidak tepat.</translation>
    </message>
    <message>
        <source>Payment request file handling</source>
        <translation>Pengelolaan file permintaan pembayaran</translation>
    </message>
    <message>
        <source>Payment request file cannot be read! This can be caused by an invalid payment request file.</source>
        <translation>File permintaan pembayaran tidak bisa dibaca! Hal ini bisa disebabkan karena file permintaan pembayaran tidak valid.</translation>
    </message>
    <message>
        <source>Payment request rejected</source>
        <translation>Permintaan pembayaran ditolak</translation>
    </message>
    <message>
        <source>Payment request network doesn't match client network.</source>
        <translation>Jaringan permintaan pembayaran tidak sesuai dengan jaringan klien.</translation>
    </message>
    <message>
        <source>Payment request expired.</source>
        <translation>Permintaan pembayaran telah kadaluarsa.</translation>
    </message>
    <message>
        <source>Payment request is not initialized.</source>
        <translation>Permintaan pembayaran tidak terinisialisasi</translation>
    </message>
    <message>
        <source>Payment request %1 is too large (%2 bytes, allowed %3 bytes).</source>
        <translation>Permintaan pembayaran %1 terlalu besar (%2 bita, diperbolehkan %3 bita)</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>User Agent</source>
        <translation>Agen Pengguna</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Terkirim</translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Diterima</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Nilai</translation>
    </message>
    <message>
        <source>Enter a Litecoin address (e.g. %1)</source>
        <translation>Masukkan alamat Litecoin (contoh %1)</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation>%1 Jam</translation>
    </message>
    <message>
        <source>%1 m</source>
        <translation>%1 menit</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>T/S</translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 dan %2</translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation>%1 B</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 KB</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation>%1 MB</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 GB</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>tidak diketahui</translation>
    </message>
</context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>T/S</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Versi Klien</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informasi</translation>
    </message>
    <message>
        <source>Debug window</source>
        <translation>Jendela debug</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Umum</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Waktu nyala</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Jaringan</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Jumlah hubungan</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Rantai blok</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Jumlah blok terkini</translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Diterima</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Terkirim</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versi</translation>
    </message>
    <message>
        <source>User Agent</source>
        <translation>Agen Pengguna

</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Layanan</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Waktu blok terakhir</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Buka</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konsol</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>Kemacetan &amp;Jaringan </translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Masuk:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Keluar:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Berkas catatan debug</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Bersihkan konsol</translation>
    </message>
    <message>
        <source>1 &amp;hour</source>
        <translation>1 &amp;jam</translation>
    </message>
    <message>
        <source>1 &amp;day</source>
        <translation>1 &amp;hari</translation>
    </message>
    <message>
        <source>1 &amp;week</source>
        <translation>1 &amp;minggu</translation>
    </message>
    <message>
        <source>1 &amp;year</source>
        <translation>1 &amp;tahun</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ya</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Tidak</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Tidak diketahui</translation>
    </message>
</context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;Nilai:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Label:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;Pesan:</translation>
    </message>
    <message>
        <source>An optional label to associate with the new receiving address.</source>
        <translation>Label opsional untuk mengasosiasikan dengan alamat penerima baru.</translation>
    </message>
    <message>
        <source>Use this form to request payments. All fields are &lt;b&gt;optional&lt;/b&gt;.</source>
        <translation>Gunakan form ini untuk meminta pembayaran. Semua bidang adalah &lt;b&gt;opsional&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>An optional amount to request. Leave this empty or zero to not request a specific amount.</source>
        <translation>Nilai permintaan opsional. Biarkan ini kosong atau nol bila tidak meminta nilai tertentu.</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Hapus informasi dari form.</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Hapus</translation>
    </message>
    <message>
        <source>Requested payments history</source>
        <translation>Riwayat pembayaran yang diminta Anda</translation>
    </message>
    <message>
        <source>&amp;Request payment</source>
        <translation>&amp;Minta pembayaran</translation>
    </message>
    <message>
        <source>Show the selected request (does the same as double clicking an entry)</source>
        <translation>Menunjukkan permintaan yang dipilih (sama dengan tekan pilihan dua kali)</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Menunjukkan</translation>
    </message>
    <message>
        <source>Remove the selected entries from the list</source>
        <translation>Menghapus informasi terpilih dari daftar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Menghapus</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Salin label</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Salin Jumlah</translation>
    </message>
</context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>QR Code</source>
        <translation>Kode QR</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation>Salin &amp;URI</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>Salin &amp;Alamat</translation>
    </message>
    <message>
        <source>&amp;Save Image...</source>
        <translation>&amp;Simpan Gambaran...</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Alamat</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Jumlah</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Dompet</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(tidak ada label)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Kirim Koin</translation>
    </message>
    <message>
        <source>Coin Control Features</source>
        <translation>Cara Pengaturan Koin</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Masukan...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>Pemilihan otomatis</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Saldo tidak mencukupi!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Kuantitas:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bytes:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Nilai:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Biaya:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Dengan Biaya:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Uang Kembali:</translation>
    </message>
    <message>
        <source>If this is activated, but the change address is empty or invalid, change will be sent to a newly generated address.</source>
        <translation>Jiki ini dipilih, tetapi alamat pengembalian uang kosong atau salah, uang kembali akan dikirim ke alamat yang baru dibuat.</translation>
    </message>
    <message>
        <source>Custom change address</source>
        <translation>Alamat uang kembali yang kustom</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation>Biaya Transaksi:</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Sembunyikan</translation>
    </message>
    <message>
        <source>Recommended:</source>
        <translation>Disarankan</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Kirim ke beberapa penerima sekaligus</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Tambahlah &amp;Penerima</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Hapus informasi dari form.</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Dust:</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Hapus &amp;Semua</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Saldo:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Konfirmasi aksi pengiriman</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>K&amp;irim</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Salin Kuantitas</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Salin Jumlah</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Salin biaya</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Salin Setelah Upah</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Salin bytes</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Salin dust</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Salin Perubahan</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Biaya Transaksi</translation>
    </message>
    <message>
        <source>Payment request expired.</source>
        <translation>Permintaan pembayaran telah kadaluarsa.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(tidak ada label)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>J&amp;umlah:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Kirim &amp;Ke:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Label:</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>Pilih alamat yang telah digunakan sebelumnya</translation>
    </message>
    <message>
        <source>This is a normal payment.</source>
        <translation>Ini adalah pembayaran normal</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+J</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Tempel alamat dari salinan</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <source>Remove this entry</source>
        <translation>Hapus masukan ini</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Pesan:</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to the list of used addresses</source>
        <translation>Masukkan label untuk alamat ini untuk dimasukan dalam daftar alamat yang pernah digunakan</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>Kirim Ke:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Catatan Peringatan:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>Do not shut down the computer until this window disappears.</source>
        <translation>Kamu tidak dapat mematikan komputer sebelum jendela ini tertutup sendiri.</translation>
    </message>
</context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Tanda Tangan / Verifikasi sebuah Pesan</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Tandakan Pesan</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>Pilih alamat yang telah digunakan sebelumnya</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Tempel alamat dari salinan</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Masukan pesan yang ingin ditandai disini</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Tanda Tangan</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Salin tanda tangan terpilih ke sistem klipboard</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Litecoin address</source>
        <translation>Tandai pesan untuk menyetujui kamu pemiliki alamat Litecoin ini</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Tandakan &amp;Pesan</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Hapus semua bidang penanda pesan</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Hapus &amp;Semua</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verifikasi Pesan</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation>Verifikasi &amp;Pesan</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Hapus semua bidang verifikasi pesan</translation>
    </message>
    </context>
<context>
    <name>SplashScreen</name>
    <message>
        <source>[testnet]</source>
        <translation>[testnet]</translation>
    </message>
</context>
<context>
    <name>TrafficGraphWidget</name>
    <message>
        <source>KB/s</source>
        <translation>KB/s</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Amount</source>
        <translation>Jumlah</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Jendela ini menampilkan deskripsi rinci dari transaksi tersebut</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(tidak ada label)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Copy address</source>
        <translation>Salin alamat</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Salin label</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Salin Jumlah</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Salain ID Transaksi</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Berkas yang berformat(*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Alamat</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Mengekspor Gagal</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>default wallet</source>
        <translation>wallet default</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Litecoin Core</source>
        <translation>Litecoin Core</translation>
    </message>
    <message>
        <source>Corrupted block database detected</source>
        <translation>Menemukan database blok yang rusak </translation>
    </message>
    <message>
        <source>Do you want to rebuild the block database now?</source>
        <translation>Apakah Anda ingin coba membangun kembali database blok sekarang?</translation>
    </message>
    <message>
        <source>Error initializing block database</source>
        <translation>Kesalahan menginisialisasi database blok</translation>
    </message>
    <message>
        <source>Error initializing wallet database environment %s!</source>
        <translation>Kesalahan menginisialisasi dompet pada database%s!</translation>
    </message>
    <message>
        <source>Error loading block database</source>
        <translation>Gagal memuat database blok</translation>
    </message>
    <message>
        <source>Error opening block database</source>
        <translation>Menemukan masalah membukakan database blok</translation>
    </message>
    <message>
        <source>Error: Disk space is low!</source>
        <translation>Gagal: Hard disk hampir terisi!</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>mengimpor...</translation>
    </message>
    <message>
        <source>Incorrect or no genesis block found. Wrong datadir for network?</source>
        <translation>Tidak bisa cari blok pertama, atau blok pertama salah. Salah direktori untuk jaringan?</translation>
    </message>
    <message>
        <source>Not enough file descriptors available.</source>
        <translation>Deskripsi berkas tidak tersedia dengan cukup.</translation>
    </message>
    <message>
        <source>Verifying blocks...</source>
        <translation>Blok-blok sedang diverifikasi...</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informasi</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation>Tandatangani transaksi tergagal</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation>Nilai transaksi terlalu kecil</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>Transaksi terlalu besar</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Peringatan</translation>
    </message>
    <message>
        <source>Zapping all transactions from wallet...</source>
        <translation>Setiap transaksi dalam dompet sedang di-'Zap'...</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Jaringan tidak diketahui yang ditentukan dalam -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Saldo tidak mencukupi</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Memuat indeks blok...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Memuat dompet...</translation>
    </message>
    <message>
        <source>Cannot downgrade wallet</source>
        <translation>Tidak dapat menurunkan versi dompet</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Memindai ulang...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Memuat selesai</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Gagal</translation>
    </message>
</context>
</TS>